@@ -62,3 +62,6 @@ from je_auto_control.utils.test_record.record_test_class import test_record
 # utils image
 from je_auto_control.wrapper.auto_control_image import screenshot
 
+# html report
+
+from je_auto_control.utils.html_report.html_report_generate import generate_html
